@@ -1,6 +1,6 @@
 import json
 
-from ocp_resources.resource import NamespacedResource
+from ocp_resources.resource import NamespacedResource, Resource
 
 
 class Template(NamespacedResource):
@@ -15,8 +15,9 @@ class Template(NamespacedResource):
 
     class Workload:
         DESKTOP = "desktop"
-        HIGH_PERFORMANCE = "highperformance"
+        HIGHPERFORMANCE = "highperformance"
         SERVER = "server"
+        SAPHANA = "saphana"
 
     class Flavor:
         LARGE = "large"
@@ -34,6 +35,11 @@ class Template(NamespacedResource):
             f"{NamespacedResource.ApiGroup.TEMPLATE_KUBEVIRT_IO}/provider-url"
         )
 
+    class VMAnnotations:
+        OS = f"{Resource.ApiGroup.VM_KUBEVIRT_IO}/os"
+        FLAVOR = f"{Resource.ApiGroup.VM_KUBEVIRT_IO}/flavor"
+        WORKLOAD = f"{Resource.ApiGroup.VM_KUBEVIRT_IO}/workload"
+
     def process(self, client=None, **kwargs):
         client = client or self.client
         instance_dict = self.instance.to_dict()
